==> applet-sa-boot-starter-3.0.0-sources.jar: cn/sinozg/applet/common/sa/SaTokenRedisJackson.java <==
package cn.sinozg.applet.common.sa;

import cn.dev33.satoken.dao.SaTokenDao;
import cn.dev33.satoken.strategy.SaStrategy;
import cn.dev33.satoken.util.SaFoxUtil;
import cn.sinozg.applet.common.utils.RedisUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
* Sa-Token 持久层实现 [Redis存储、Jackson序列化]
* @Author: xyb
* @Description: 
* @Date: 2022-11-14 下午 10:19
**/
@Component
public class SaTokenRedisJackson implements SaTokenDao {
    public boolean isInit;
    private final Logger log = LoggerFactory.getLogger(SaTokenRedisJackson.class);
    @Bean
    @Override
    public void init() {
        if (!this.isInit) {
            SaStrategy.instance.createSession = SaSessionForJacksonCustomized::new;
        }
    }

    /**
     * 获取Value，如无返空
     * @param key key值
     * @return 结果
     */
    @Override
    public String get(String key) {
        return RedisUtil.getCacheObject(key);
    }

    /**
     * 写入Value，并设定存活时间 (单位: 秒)
     * @param key key值
     * @param value value值
     * @param timeout 过期时间
     */
    @Override
    public void set(String key, String value, long timeout) {
        this.setValue(key, value, timeout);
    }


    /**
     * 修修改指定key-value键值对 (过期时间不变)
     * @param key key值
     * @param value value值
     */
    @Override
    public void update(String key, String value) {
        long expire = getTimeout(key);
        // -2 = 无此键
        if (expire == SaTokenDao.NOT_VALUE_EXPIRE) {
            return;
        }
        this.set(key, value, expire);
    }

    /**
     * 删除Value
     * @param key key值
     */
    @Override
    public void delete(String key) {
        RedisUtil.deleteObject(key);
    }

    /**
     * 获取Value的剩余存活时间 (单位: 秒)
     * @param key key值
     * @return 过期时间
     */
    @Override
    public long getTimeout(String key) {
        return RedisUtil.objExpireTime(key);
    }

    /**
     * 修改Value的剩余存活时间 (单位: 秒)
     * @param key key值
     * @param timeout 过期时间
     */
    @Override
    public void updateTimeout(String key, long timeout) {
        // 判断是否想要设置为永久
        if (timeout == SaTokenDao.NEVER_EXPIRE) {
            long expire = getTimeout(key);
            // 如果其已经被设置为永久，则不作任何处理
            // 如果尚未被设置为永久，那么再次set一次
            if (expire != SaTokenDao.NEVER_EXPIRE) {
                this.set(key, this.get(key), timeout);
            }
            return;
        }
        RedisUtil.expire(key, timeout, TimeUnit.SECONDS);
    }

    /**
     * 获取Object，如无返空
     * @param key key值
     * @return 结果
     */
    @Override
    public Object getObject(String key) {
        return RedisUtil.getCacheObject(key);
    }

    /**
     * 写入Object，并设定存活时间 (单位: 秒)
     * @param key key值
     * @param object 对象的值
     * @param timeout 过期时间
     */
    @Override
    public void setObject(String key, Object object, long timeout) {
        this.setValue(key, object, timeout);
    }

    /**
     * 更新Object (过期时间不变)
     * @param key key值
     * @param object 对象的值
     */
    @Override
    public void updateObject(String key, Object object) {
        long expire = getObjectTimeout(key);
        // -2 = 无此键
        if (expire == SaTokenDao.NOT_VALUE_EXPIRE) {
            return;
        }
        this.setObject(key, object, expire);
    }

    /**
     * 删除Object
     * @param key key值
     */
    @Override
    public void deleteObject(String key) {
        RedisUtil.deleteObject(key);
    }


    /**
     * 获取Object的剩余存活时间 (单位: 秒)
     * @param key key值
     * @return 存活时间
     */
    @Override
    public long getObjectTimeout(String key) {
        return RedisUtil.objExpireTime(key);
    }

    /**
     * 修改Object的剩余存活时间 (单位: 秒)
     * @param key key值
     * @param timeout 过期时间
     */
    @Override
    public void updateObjectTimeout(String key, long timeout) {
        // 判断是否想要设置为永久
        if (timeout == SaTokenDao.NEVER_EXPIRE) {
            long expire = getObjectTimeout(key);
            if (expire != SaTokenDao.NEVER_EXPIRE) {
                this.setObject(key, this.getObject(key), timeout);
            }
            return;
        }
        RedisUtil.expire(key, timeout, TimeUnit.SECONDS);
    }

    /**
     * 搜索数据
     * @param prefix 前缀
     * @param keyword 关键词
     * @param start 开始
     * @param size 数量
     * @param sortType 排序类型
     * @return 搜索结果
     */
    @Override
    public List<String> searchData(String prefix, String keyword, int start, int size, boolean sortType) {
        String pattern = prefix + "*";
        if (StringUtils.isNotEmpty(keyword)) {
            pattern += keyword + "*";
        }
        Collection<String> keys = RedisUtil.keys(pattern);
        List<String> list = new ArrayList<>(keys);
        return SaFoxUtil.searchList(list, start, size, sortType);
    }

    /**
     * 写入Value，并设定存活时间 (单位: 秒)
     * @param key key值
     * @param value value值
     * @param timeout 过期时间
     */
    private void setValue (String key, Object value, long timeout){
        if (timeout == 0 || timeout <= SaTokenDao.NOT_VALUE_EXPIRE) {
            return;
        }
        RedisUtil.setCacheObject(key, value, timeout);
    }
}

==> applet-sa-boot-starter-3.0.2-sources.jar: cn/sinozg/applet/common/sa/SaTokenRedisJackson.java <==
package cn.sinozg.applet.common.sa;

import cn.dev33.satoken.dao.SaTokenDao;
import cn.dev33.satoken.strategy.SaStrategy;
import cn.dev33.satoken.util.SaFoxUtil;
import cn.sinozg.applet.common.constant.BaseConstants;
import cn.sinozg.applet.common.utils.RedisUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
* Sa-Token 持久层实现 [Redis存储、Jackson序列化]
* @Author: xyb
* @Description: 
* @Date: 2022-11-14 下午 10:19
**/
@Component
public class SaTokenRedisJackson implements SaTokenDao {

    public boolean isInit;

    private final Logger log = LoggerFactory.getLogger(SaTokenRedisJackson.class);

    @Bean
    @Override
    public void init() {
        if (!this.isInit) {
            SaStrategy.instance.createSession = SaSessionForJacksonCustomized::new;
        }
    }

    /**
     * 获取Value，如无返空
     * @param key key值
     * @return 结果
     */
    @Override
    public String get(String key) {
        return RedisUtil.getCacheObject(key);
    }

    /**
     * 写入Value，并设定存活时间 (单位: 秒)
     * @param key key值
     * @param value value值
     * @param timeout 过期时间
     */
    @Override
    public void set(String key, String value, long timeout) {
        this.setValue(key, value, timeout);
    }

    /**
     * 修修改指定key-value键值对 (过期时间不变)
     * @param key key值
     * @param value value值
     */
    @Override
    public void update(String key, String value) {
        long expire = getTimeout(key);
        // -2 = 无此键
        if (expire == SaTokenDao.NOT_VALUE_EXPIRE) {
            return;
        }
        this.set(key, value, expire);
    }

    /**
     * 删除Value
     * @param key key值
     */
    @Override
    public void delete(String key) {
        RedisUtil.deleteObject(key);
    }

    /**
     * 获取Value的剩余存活时间 (单位: 秒)
     * @param key key值
     * @return 过期时间
     */
    @Override
    public long getTimeout(String key) {
        return RedisUtil.objExpireTime(key);
    }

    /**
     * 修改Value的剩余存活时间 (单位: 秒)
     * @param key key值
     * @param timeout 过期时间
     */
    @Override
    public void updateTimeout(String key, long timeout) {
        // 判断是否想要设置为永久
        if (timeout == SaTokenDao.NEVER_EXPIRE) {
            long expire = getTimeout(key);
            // 如果其已经被设置为永久，则不作任何处理
            // 如果尚未被设置为永久，那么再次set一次
            if (expire != SaTokenDao.NEVER_EXPIRE) {
                this.set(key, this.get(key), timeout);
            }
            return;
        }
        RedisUtil.expire(key, timeout, TimeUnit.SECONDS);
    }

    /**
     * 获取Object，如无返空
     * @param key key值
     * @return 结果
     */
    @Override
    public Object getObject(String key) {
        return RedisUtil.getCacheObject(key);
    }

    /**
     * 写入Object，并设定存活时间 (单位: 秒)
     * @param key key值
     * @param object 对象的值
     * @param timeout 过期时间
     */
    @Override
    public void setObject(String key, Object object, long timeout) {
        this.setValue(key, object, timeout);
    }

    /**
     * 更新Object (过期时间不变)
     * @param key key值
     * @param object 对象的值
     */
    @Override
    public void updateObject(String key, Object object) {
        long expire = getObjectTimeout(key);
        // -2 = 无此键
        if (expire == SaTokenDao.NOT_VALUE_EXPIRE) {
            return;
        }
        this.setObject(key, object, expire);
    }

    /**
     * 删除Object
     * @param key key值
     */
    @Override
    public void deleteObject(String key) {
        RedisUtil.deleteObject(key);
    }


    /**
     * 获取Object的剩余存活时间 (单位: 秒)
     * @param key key值
     * @return 存活时间
     */
    @Override
    public long getObjectTimeout(String key) {
        return RedisUtil.objExpireTime(key);
    }

    /**
     * 修改Object的剩余存活时间 (单位: 秒)
     * @param key key值
     * @param timeout 过期时间
     */
    @Override
    public void updateObjectTimeout(String key, long timeout) {
        // 判断是否想要设置为永久
        if (timeout == SaTokenDao.NEVER_EXPIRE) {
            long expire = getObjectTimeout(key);
            if (expire != SaTokenDao.NEVER_EXPIRE) {
                this.setObject(key, this.getObject(key), timeout);
            }
            return;
        }
        RedisUtil.expire(key, timeout, TimeUnit.SECONDS);
    }

    /**
     * 搜索数据
     * @param prefix 前缀
     * @param keyword 关键词
     * @param start 开始
     * @param size 数量
     * @param sortType 排序类型
     * @return 搜索结果
     */
    @Override
    public List<String> searchData(String prefix, String keyword, int start, int size, boolean sortType) {
        String pattern = prefix + BaseConstants.ALL;
        if (StringUtils.isNotEmpty(keyword)) {
            pattern += keyword + BaseConstants.ALL;
        }
        Collection<String> keys = RedisUtil.keys(pattern);
        List<String> list = new ArrayList<>(keys);
        return SaFoxUtil.searchList(list, start, size, sortType);
    }

    /**
     * 写入Value，并设定存活时间 (单位: 秒)
     * @param key key值
     * @param value value值
     * @param timeout 过期时间
     */
    private void setValue (String key, Object value, long timeout){
        if (timeout == 0 || timeout <= SaTokenDao.NOT_VALUE_EXPIRE) {
            return;
        }
        RedisUtil.setCacheObject(key, value, timeout);
    }
}
